From: Joseph S <jks@selectacast.net>
To: pgsql-performance@postgresql.org
Subject: Horrible trigger performance after upgrade 8.0.12 -> 8.2.3
Date: Tue, 20 Mar 2007 15:26:33 -0400
Message-ID: <etpch9$bue$1@news.hub.org> (raw)
After upgrading to 8.2.3 INSERTs and UPDATEs on one of my tables became
incredibly slow. I traced the problem to one of my triggers that calls
one of my defined functions (that is IMMUTABLE). If I inline the
function instead of calling it the runtime for my test update drops from
10261.234 ms to 564.094 ms. The time running the trigger itself
dropped from 9749.910 to 99.504.
BTW does make any sense to bother marking trigger functions as STABLE or
IMMUTABLE?
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-performance@postgresql.org
Cc: jks@selectacast.net
Subject: Re: Horrible trigger performance after upgrade 8.0.12 -> 8.2.3
In-Reply-To: <etpch9$bue$1@news.hub.org>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox